Payload

Enum Payload 

pub enum Payload {
    PubkeyHash(PubkeyHash),
    ScriptHash(ScriptHash),
    WitnessProgram {
        version: WitnessVersion,
        program: Vec<u8>,
    },
}
The method used to produce an address.

Variants



PubkeyHash(PubkeyHash)

P2PKH address.



ScriptHash(ScriptHash)

P2SH address.



WitnessProgram

Segwit address.

Fields

version: WitnessVersion

The witness program version.

program: Vec<u8>

The witness program.

Implementations

Source

impl Payload

pub fn from_script(script: &Script) -> Option<Payload>

Constructs a Payload from an output script (scriptPubkey).

pub fn script_pubkey(&self) -> Script

Generates a script pubkey spending to this Payload.

pub fn p2pkh(pk: &PublicKey) -> Payload

Creates a pay to (compressed) public key hash payload from a public key

pub fn p2sh(script: &Script) -> Result<Payload, Error>

Creates a pay to script hash P2SH payload from a script

pub fn p2wpkh(pk: &PublicKey) -> Result<Payload, Error>

Create a witness pay to public key payload from a public key

pub fn p2shwpkh(pk: &PublicKey) -> Result<Payload, Error>

Create a pay to script payload that embeds a witness pay to public key

pub fn p2wsh(script: &Script) -> Payload

Create a witness pay to script hash payload.

pub fn p2shwsh(script: &Script) -> Payload

Create a pay to script payload that embeds a witness pay to script hash address

pub fn p2tr<C: Verification>( secp: &Secp256k1<C>, internal_key: UntweakedPublicKey, merkle_root: Option<TapBranchHash>, ) -> Payload

Create a pay to taproot payload from untweaked key

pub fn p2tr_tweaked(output_key: TweakedPublicKey) -> Payload

Create a pay to taproot payload from a pre-tweaked output key.

This method is not recommended for use and Payload::p2tr() should be used where possible.